using System;
using System.Threading.Tasks;
using Microsoft.AspNetCore.Mvc;
using WebApplication1.Models;
using WebApplication1.Services;

namespace WebApplication1.Controllers
{
    public class ReservationController : Controller
    {
        private readonly ReservationService _reservationService;

        public ReservationController(ReservationService reservationService)
        {
            _reservationService = reservationService;
        }

        // 初期表示アクション
        public async Task<IActionResult> Index()
        {
            // (comment Start) ユーザ情報を取得し本画面の権限を確認 (comment End)
            // (comment Start) ログイン情報を取得する為、ユーザ共通クラスを呼び出す。 (comment End)
            // (comment Start) 本画面を使用できるかの確認をする為、権限共通処理を呼び出す。 (comment End)

            // ここでユーザーIDを取得する想定（例: ログインセッションから取得）
            int userId = 1; // 仮のユーザーID

            await _reservationService.InitializeAsync(userId);

            // 画面表示用のデータを準備する
            // ここでは具体的な実装は省略し、ViewDataなどを使用してデータをViewに渡す想定

            return View();
        }

        // 会議室選択時アクション
        [HttpPost]
        public async Task<IActionResult> SelectMeetingRoom(int meetingRoomId)
        {
            // (comment Start) 選択された会議室がある場合 (comment End)
            await _reservationService.SelectMeetingRoomAsync(meetingRoomId);

            // 画面表示用のデータを準備する
            // ここでは具体的な実装は省略し、ViewDataなどを使用してデータをViewに渡す想定

            return View("Index");
        }

        // 予約するボタン押下時アクション
        [HttpPost]
        public async Task<IActionResult> Reserve(Reservation reservation, bool isNew)
        {
            // (comment Start) 入力値のチェック (comment End)
            bool result = await _reservationService.ReserveAsync(reservation, isNew);

            if (!result)
            {
                // (comment Start) エラーメッセージを表示する (comment End)
                // ここでは具体的な実装は省略し、ViewDataなどを使用してエラーメッセージをViewに渡す想定
                return View("Index");
            }

            // 予約成功時の処理
            // 予約完了画面へリダイレクトするなどの処理を想定
            return RedirectToAction("Complete");
        }

        // 予約完了画面表示アクション
        public IActionResult Complete()
        {
            return View();
        }
    }
}