using System;
using System.Collections.Generic;
using System.Linq;
using System.Threading.Tasks;
using Microsoft.EntityFrameworkCore;
using WebApplication1.Models;

namespace WebApplication1.Repositories
{
    public class ReservationRepository
    {
        private readonly DbContext _context;

        public ReservationRepository(DbContext context)
        {
            _context = context;
        }

        // 会議室マスターから全データを取得する
        public async Task<List<MeetingRoom>> GetAllMeetingRoomsAsync()
        {
            return await _context.Set<MeetingRoom>().ToListAsync();
        }

        // ログインユーザーを条件にして予約情報を取得しておき、予約情報リストに設定しておく
        public async Task<List<Reservation>> GetReservationsByUserIdAsync(int userId)
        {
            return await _context.Set<Reservation>().Where(r => r.UserId == userId).ToListAsync();
        }

        // 指定された予約の識別番号を元に予約情報を検索する
        public async Task<Reservation> GetReservationByIdAsync(int reservationId)
        {
            return await _context.Set<Reservation>().FindAsync(reservationId);
        }

        // 予約情報にログインユーザーと同じ部署の予約情報を検索し、利用料金を合計する
        public async Task<int> GetTotalReservationCostByDepartmentIdAsync(int departmentId)
        {
            return await _context.Set<Reservation>()
                .Include(r => r.User)
                .Where(r => r.User.DepartmentId == departmentId)
                .SumAsync(r => r.MeetingRoom.HourlyRate.HasValue ? r.MeetingRoom.HourlyRate.Value : 0);
        }

        // ログインユーザーの部署を検索し、部署の予算を検索する
        public async Task<Department> GetDepartmentByIdAsync(int departmentId)
        {
            return await _context.Set<Department>().FindAsync(departmentId);
        }

        // ログインユーザーの情報を検索し、ユーザーが予約できる会議室の数を取得する
        public async Task<User> GetUserByIdAsync(int userId)
        {
            return await _context.Set<User>().FindAsync(userId);
        }

        // ログインユーザーが予約している予約情報を検索し、件数を取得する
        public async Task<int> GetReservationCountByUserIdAsync(int userId)
        {
            return await _context.Set<Reservation>().CountAsync(r => r.UserId == userId);
        }

        // 画面の入力内容をデータベースに登録する
        public async Task AddReservationAsync(Reservation reservation)
        {
            await _context.Set<Reservation>().AddAsync(reservation);
            await _context.SaveChangesAsync();
        }

        // 画面の入力内容をデータベースに更新する
        public async Task UpdateReservationAsync(Reservation reservation)
        {
            _context.Set<Reservation>().Update(reservation);
            await _context.SaveChangesAsync();
        }
    }
}