using System;
using System.Collections.Generic;
using System.Linq;
using System.Threading.Tasks;
using WebApplication1.Models;
using WebApplication1.Repositories;

namespace WebApplication1.Services
{
    public class ReservationService
    {
        private readonly ReservationRepository _reservationRepository;

        public ReservationService(ReservationRepository reservationRepository)
        {
            _reservationRepository = reservationRepository;
        }

        // 初期表示時の処理を行う
        public async Task InitializeAsync(int userId)
        {
            // ユーザ情報を取得し本画面の権限を確認
            // (comment Start) ログイン情報を取得する為、ユーザ共通クラスを呼び出す。(comment End)
            // (comment Start) 本画面を使用できるかの確認をする為、権限共通処理を呼び出す。(comment End)

            // 会議室データを読み込む
            var meetingRooms = await _reservationRepository.GetAllMeetingRoomsAsync();
            // 会議室項目へ会議室名を設定する。値は会議室IDを用いる

            // 予約情報を取得する
            var reservations = await _reservationRepository.GetReservationsByUserIdAsync(userId);
            // 予約情報リストに設定しておく

            // 新規の場合
            // ログインしているユーザーを設定する
            // (comment Start) ログイン情報に持っているユーザーIDを画面の予約者IDに設定する(comment End)
            // (comment Start) ログイン情報に持っているユーザー名を画面の予約者に設定する(comment End)

            // 修正の場合
            // 一覧で選択された予約情報を検索して表示する
            // (comment Start) 指定された予約の識別番号を元に予約情報を検索する(comment End)
            // (comment Start) 取得した予約情報からユーザーIDを画面の予約者IDに設定する(comment End)
            // (comment Start) 取得した予約情報からユーザー名を画面の予約者に設定する(comment End)
            // (comment Start) 取得した予約情報から参加者を画面の参加者に設定する(comment End)
            // (comment Start) 取得した予約情報から目的を画面の目的に設定する(comment End)
            // (comment Start) 取得した予約情報からタイトルを画面のタイトルに設定する(comment End)
            // (comment Start) 取得した予約情報から開始日時を画面の開始日時に設定する(comment End)
            // (comment Start) 取得した予約情報から終了日時を画面の終了日時に設定する(comment End)
        }

        // 会議室選択時の処理を行う
        public async Task SelectMeetingRoomAsync(int meetingRoomId)
        {
            // 選択された会議室がある場合
            var meetingRoom = await _reservationRepository.GetReservationByIdAsync(meetingRoomId);
            // 会議室情報から会議室の利用料金（1時間あたり）を取得して画面に表示する
        }

        // 予約するボタン押下時の処理を行う
        public async Task<bool> ReserveAsync(Reservation reservation, bool isNew)
        {
            // 入力値のチェック
            if (isNew)
            {
                // 新規の場合
                // 利用料金が部の予算を超えているかチェックする
                var totalCost = await _reservationRepository.GetTotalReservationCostByDepartmentIdAsync(reservation.User.DepartmentId.Value);
                var department = await _reservationRepository.GetDepartmentByIdAsync(reservation.User.DepartmentId.Value);
                if (totalCost + reservation.MeetingRoom.HourlyRate > department.DepartmentBudget)
                {
                    // メッセージエリアに「部の予算を超えているため、会議室の予約ができません。」を表示する
                    return false;
                }

                // ユーザーの予約数を超えているかチェックする
                var user = await _reservationRepository.GetUserByIdAsync(reservation.UserId);
                var reservationCount = await _reservationRepository.GetReservationCountByUserIdAsync(reservation.UserId);
                if (reservationCount + 1 > user.ReservableNumber)
                {
                    // メッセージエリアに「予約できる件数を超えているため、会議室の予約ができません。」を表示する
                    return false;
                }

                // 画面の入力内容をデータベースに登録する
                await _reservationRepository.AddReservationAsync(reservation);
            }
            else
            {
                // 修正の場合
                // 利用料金が変更されているか？
                var originalReservation = await _reservationRepository.GetReservationByIdAsync(reservation.ReservationId);
                if (originalReservation.MeetingRoom.HourlyRate != reservation.MeetingRoom.HourlyRate)
                {
                    // 利用料金が部の予算を超えているかチェックする
                    var totalCost = await _reservationRepository.GetTotalReservationCostByDepartmentIdAsync(reservation.User.DepartmentId.Value);
                    var department = await _reservationRepository.GetDepartmentByIdAsync(reservation.User.DepartmentId.Value);
                    if (totalCost - originalReservation.MeetingRoom.HourlyRate + reservation.MeetingRoom.HourlyRate > department.DepartmentBudget)
                    {
                        // メッセージエリアに「部の予算を超えているため、会議室の予約ができません。」を表示する
                        return false;
                    }
                }

                // 画面の入力内容をデータベースに更新する
                await _reservationRepository.UpdateReservationAsync(reservation);
            }

            return true;
        }
    }
}