package com.example.controller;

import com.example.entity.ReservationEntity;
import com.example.form.ReservationForm;
import com.example.service.ReservationService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.validation.BindingResult;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.servlet.ModelAndView;

import java.math.BigDecimal;

/**
 * 会議室予約登録コントローラ
 */
@Controller
@RequestMapping("/reservation")
public class ReservationController {

    @Autowired
    private ReservationService reservationService;

    /**
     * 予約登録画面の初期表示
     * @param modelAndView モデルおよびビュー情報
     * @return モデルおよびビュー情報
     */
    @GetMapping("/register")
    public ModelAndView init(ModelAndView modelAndView) {
        modelAndView.setViewName("reservationRegister");
        // (comment Start) ユーザ情報を取得し本画面の権限を確認 (comment End)
        // ユーザ情報取得と権限確認のロジックは省略
        // (comment Start) 会議室データを読み込む (comment End)
        // 会議室データ読み込みのロジックは省略
        // (comment Start) 新規の場合 (comment End)
        // 新規登録のロジックは省略
        return modelAndView;
    }

    /**
     * 予約情報の登録
     * @param reservationForm 予約情報フォーム
     * @param result バインディング結果
     * @param modelAndView モデルおよびビュー情報
     * @return モデルおよびビュー情報
     */
    @PostMapping("/save")
    public ModelAndView save(@ModelAttribute @Validated ReservationForm reservationForm, BindingResult result, ModelAndView modelAndView) {
        modelAndView.setViewName("reservationRegister");
        if (result.hasErrors()) {
            // フォームのバリデーションエラーがある場合
            return modelAndView;
        }
        // (comment Start) 入力値のチェック (comment End)
        // 入力値チェックのビジネスロジックは省略
        // (comment Start) 登録 (comment End)
        ReservationEntity reservationEntity = new ReservationEntity();
        // 予約情報エンティティへのマッピングは省略
        reservationService.createReservation(reservationEntity);
        modelAndView.addObject("message", "予約が完了しました。");
        return modelAndView;
    }

    /**
     * 予約情報の更新
     * @param reservationId 予約の識別番号
     * @param reservationForm 予約情報フォーム
     * @param result バインディング結果
     * @param modelAndView モデルおよびビュー情報
     * @return モデルおよびビュー情報
     */
    @PostMapping("/update/{reservationId}")
    public ModelAndView update(@PathVariable BigDecimal reservationId, @ModelAttribute @Validated ReservationForm reservationForm, BindingResult result, ModelAndView modelAndView) {
        modelAndView.setViewName("reservationRegister");
        if (result.hasErrors()) {
            // フォームのバリデーションエラーがある場合
            return modelAndView;
        }
        // (comment Start) 入力値のチェック (comment End)
        // 入力値チェックのビジネスロジックは省略
        // (comment Start) 登録 (comment End)
        ReservationEntity reservationEntity = reservationService.getReservationById(reservationId);
        // 予約情報エンティティへのマッピングは省略
        reservationService.updateReservation(reservationEntity);
        modelAndView.addObject("message", "予約情報を更新しました。");
        return modelAndView;
    }
}