package com.example.entity;

import lombok.Data;
import javax.persistence.*;
import java.math.BigDecimal;
import java.sql.Timestamp;

/**
 * 予約情報 Entity
 */
@Entity
@Table(name = "reservations")
@Data
public class ReservationEntity {

    /**
     * 予約の識別番号
     */
    @Id
    @GeneratedValue(strategy = GenerationType.IDENTITY)
    @Column(name = "reservation_id", nullable = false)
    private BigDecimal reservationId;

    /**
     * 予約された会議室
     */
    @ManyToOne(fetch = FetchType.LAZY)
    @JoinColumn(name = "meeting_room_id", nullable = false)
    private MeetingRoomEntity meetingRoom;

    /**
     * 予約したユーザー
     */
    @ManyToOne(fetch = FetchType.LAZY)
    @JoinColumn(name = "user_id", nullable = false)
    private UserEntity user;

    /**
     * 会議に参加するユーザー
     */
    @Column(name = "participants", length = 255)
    private String participants;

    /**
     * 会議の目的
     */
    @Column(name = "purpose", length = 255)
    private String purpose;

    /**
     * 会議のタイトル
     */
    @Column(name = "title", length = 255)
    private String title;

    /**
     * 会議の開始日時
     */
    @Column(name = "start_datetime")
    private Timestamp startDatetime;

    /**
     * 会議の終了日時
     */
    @Column(name = "end_datetime")
    private Timestamp endDatetime;

    /**
     * 予約した日時
     */
    @Column(name = "reservation_datetime")
    private Timestamp reservationDatetime;

    /**
     * 予約の状態
     */
    @Column(name = "status", length = 255, nullable = false)
    private String status;
}