package com.example.form;

import lombok.Data;
import org.springframework.format.annotation.DateTimeFormat;

import javax.validation.constraints.*;
import java.math.BigDecimal;
import java.time.LocalDateTime;

/**
 * 会議室予約登録フォーム
 */
@Data
public class ReservationForm {

    /**
     * 会議室ID
     */
    private BigDecimal meetingRoomId;

    /**
     * 予約者ID
     */
    private BigDecimal userId;

    /**
     * 予約者名
     */
    private String userName;

    /**
     * 参加者
     */
    private String participants;

    /**
     * 目的
     */
    private String purpose;

    /**
     * タイトル
     */
    private String title;

    /**
     * 開始日時
     */
    @NotNull(message = "MSG00002")
    @DateTimeFormat(pattern = "yyyy/MM/dd HH:mm:ss")
    private LocalDateTime startDatetime;

    /**
     * 終了日時
     */
    @NotNull(message = "MSG00003")
    @DateTimeFormat(pattern = "yyyy/MM/dd HH:mm:ss")
    private LocalDateTime endDatetime;

    /**
     * 予約状態
     */
    private String reservationStatus;

    /**
     * 開始日時と終了日時の前後関係チェック
     */
    @AssertTrue(message = "MSG00006")
    public boolean isStartBeforeEnd() {
        if (startDatetime == null || endDatetime == null) {
            return true; // 他の@NotNullによるチェックが先に行われるため、ここではtrueを返す
        }
        return startDatetime.isBefore(endDatetime);
    }
}