package com.example.repository;

import com.example.entity.ReservationEntity;
import com.example.entity.UserEntity;
import org.springframework.data.jpa.repository.JpaRepository;
import org.springframework.stereotype.Repository;

import java.math.BigDecimal;
import java.util.List;

/**
 * 予約情報リポジトリ
 */
@Repository
public interface ReservationRepository extends JpaRepository<ReservationEntity, BigDecimal> {

    /**
     * ユーザーによる予約情報の取得
     * @param user 予約したユーザー
     * @return 予約情報リスト
     */
    List<ReservationEntity> findByUser(UserEntity user);

    /**
     * ユーザーの部署による予約情報の取得
     * @param departmentId 部署の識別番号
     * @return 予約情報リスト
     */
    List<ReservationEntity> findByUser_Department_DepartmentId(BigDecimal departmentId);
}