package com.example.service;

import com.example.entity.DepartmentEntity;
import com.example.entity.MeetingRoomEntity;
import com.example.entity.ReservationEntity;
import com.example.entity.UserEntity;
import com.example.repository.DepartmentRepository;
import com.example.repository.MeetingRoomRepository;
import com.example.repository.ReservationRepository;
import com.example.repository.UserRepository;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.math.BigDecimal;
import java.util.List;

/**
 * 予約情報サービス
 */
@Service
public class ReservationService {

    @Autowired
    private ReservationRepository reservationRepository;

    @Autowired
    private UserRepository userRepository;

    @Autowired
    private DepartmentRepository departmentRepository;

    @Autowired
    private MeetingRoomRepository meetingRoomRepository;

    /**
     * ユーザーによる予約情報の取得
     * @param userId ユーザーの識別番号
     * @return 予約情報リスト
     */
    public List<ReservationEntity> getReservationsByUserId(BigDecimal userId) {
        UserEntity user = userRepository.findById(userId).orElse(null);
        return reservationRepository.findByUser(user);
    }

    /**
     * 部署による予約情報の取得
     * @param departmentId 部署の識別番号
     * @return 予約情報リスト
     */
    public List<ReservationEntity> getReservationsByDepartmentId(BigDecimal departmentId) {
        return reservationRepository.findByUser_Department_DepartmentId(departmentId);
    }

    /**
     * 会議室情報の取得
     * @param meetingRoomId 会議室の識別番号
     * @return 会議室情報
     */
    public MeetingRoomEntity getMeetingRoomById(BigDecimal meetingRoomId) {
        return meetingRoomRepository.findById(meetingRoomId).orElse(null);
    }

    /**
     * 部署情報の取得
     * @param departmentId 部署の識別番号
     * @return 部署情報
     */
    public DepartmentEntity getDepartmentById(BigDecimal departmentId) {
        return departmentRepository.findById(departmentId).orElse(null);
    }

    /**
     * 予約情報の新規登録
     * @param reservation 予約情報エンティティ
     */
    public void createReservation(ReservationEntity reservation) {
        reservationRepository.save(reservation);
    }

    /**
     * 予約情報の更新
     * @param reservation 予約情報エンティティ
     */
    public void updateReservation(ReservationEntity reservation) {
        reservationRepository.save(reservation);
    }

    /**
     * 予約情報の取得
     * @param reservationId 予約の識別番号
     * @return 予約情報
     */
    public ReservationEntity getReservationById(BigDecimal reservationId) {
        return reservationRepository.findById(reservationId).orElse(null);
    }
}