from django.db import models

class MeetingRoom(models.Model):
    # 会議室情報
    meeting_room_id = models.AutoField(primary_key=True, db_column='meeting_room_id')
    meeting_room_name = models.CharField(max_length=255, db_column='meeting_room_name')
    location = models.CharField(max_length=255, db_column='location')
    seat_number = models.IntegerField(db_column='seat_number')
    equipment = models.CharField(max_length=255, db_column='equipment')
    available_time_slots_start = models.CharField(max_length=255, db_column='available_time_slots_start')
    available_time_slots_end = models.IntegerField(db_column='available_time_slots_end')
    hourly_rate = models.IntegerField(db_column='hourly_rate')

    class Meta:
        db_table = 'meeting_rooms'

class Department(models.Model):
    # 部情報
    department_id = models.AutoField(primary_key=True, db_column='department_id')
    department_name = models.CharField(max_length=255, db_column='department_name')
    department_budget = models.IntegerField(db_column='department_budget')

    class Meta:
        db_table = 'departments'

class User(models.Model):
    # ユーザー情報
    user_id = models.AutoField(primary_key=True, db_column='user_id')
    name = models.CharField(max_length=255, db_column='name')
    department = models.ForeignKey(Department, on_delete=models.CASCADE, db_column='department_id')
    reservable_number = models.IntegerField(db_column='reservable_number')

    class Meta:
        db_table = 'users'

class Reservation(models.Model):
    # 予約情報
    reservation_id = models.AutoField(primary_key=True, db_column='reservation_id')
    meeting_room = models.ForeignKey(MeetingRoom, on_delete=models.CASCADE, db_column='meeting_room_id')
    user = models.ForeignKey(User, on_delete=models.CASCADE, db_column='user_id')
    participants = models.CharField(max_length=255, db_column='participants')
    purpose = models.CharField(max_length=255, db_column='purpose')
    title = models.CharField(max_length=255, db_column='title')
    start_datetime = models.DateTimeField(db_column='start_datetime')
    end_datetime = models.DateTimeField(db_column='end_datetime')
    reservation_datetime = models.DateTimeField(auto_now_add=True, db_column='reservation_datetime')
    status = models.CharField(max_length=255, db_column='status', default='pending')

    class Meta:
        db_table = 'reservations'