from django.views import View
from django.shortcuts import render, redirect
from .models import MeetingRoom, Reservation, User, Department
from django.contrib.auth.mixins import LoginRequiredMixin
from django.contrib import messages

class MeetingRoomReservationView(LoginRequiredMixin, View):
    template_name = 'meeting_room_reservation.html'

    def get(self, request, *args, **kwargs):
        # アクション:初期表示
        # (comment Start) ログイン情報を取得する為、ユーザ共通クラスを呼び出す。(comment End)
        # ユーザ情報を取得し本画面の権限を確認
        # (comment Start) 本画面を使用できるかの確認をする為、権限共通処理を呼び出す。(comment End)
        
        # 会議室データを読み込む
        meeting_rooms = MeetingRoom.objects.all()
        # 予約情報を取得する
        reservations = Reservation.objects.filter(user=request.user)
        
        # 新規の場合
        if 'new' in request.GET:
            # ログインしているユーザーを設定する
            user_id = request.user.id
            user_name = request.user.name
        # 修正の場合
        elif 'edit' in request.GET:
            # 一覧で選択された予約情報を検索して表示する
            reservation_id = request.GET.get('edit')
            reservation = Reservation.objects.get(id=reservation_id)
            # 以下、取得した予約情報を画面に設定する処理
            user_id = reservation.user_id
            user_name = reservation.user.name
            # 以下、その他の予約情報を設定する処理
        
        # 以下、テンプレートに渡すコンテキストを設定する処理
        context = {
            'meeting_rooms': meeting_rooms,
            'user_id': user_id,
            'user_name': user_name,
            # 以下、その他のコンテキストを設定する処理
        }
        return render(request, self.template_name, context)

    def post(self, request, *args, **kwargs):
        # アクション:予約するボタン
        # 入力値のチェック
        # 新規の場合
        if 'new' in request.POST:
            # 利用料金が部の予算を超えているかチェックする
            # 以下、チェック処理
            # ユーザーの予約数を超えているかチェックする
            # 以下、チェック処理
        # 修正の場合
        elif 'edit' in request.POST:
            # 利用料金が変更されているか？
            # 以下、チェック処理
        
        # 登録
        # 新規の場合
        if 'new' in request.POST:
            # 画面の入力内容をデータベースに登録する
            # 以下、登録処理
        # 修正の場合
        elif 'edit' in request.POST:
            # 画面の入力内容をデータベースに更新する
            # 以下、更新処理
        
        # 以下、成功時のリダイレクト処理
        return redirect('some_success_url')